#!/bin/bash

set -e

TEST_NAME=testpypi-orthpol
ENV_NAME=venv_${TEST_NAME}_${PYTHON_EXE}_${C_COMPILER}
ENV_DIR=$HOME/workspace/${TEST_NAME}
if [ "$PYTHON_EXE" = "python2" ]; then
    CONDA_HOME=/home/dabi/anaconda2/
elif [ "$PYTHON_EXE" = "python3" ]; then
    CONDA_HOME=/home/dabi/anaconda3/
fi

if [ "$VENV_SYS" = "virtualenv" ]; then
    rm -rf $ENV_DIR/$ENV_NAME
    virtualenv --python=$PYTHON_EXE $ENV_DIR/$ENV_NAME
    source $ENV_DIR/$ENV_NAME/bin/activate
elif [ "$VENV_SYS" = "anaconda" ]; then
    $CONDA_HOME/bin/conda-env remove -y --name $ENV_NAME
    if [ "$PYTHON_EXE" = "python2" ]; then
        $CONDA_HOME/bin/conda create -y --name $ENV_NAME python=2 pip
    elif [ "$PYTHON_EXE" = "python3" ]; then
        $CONDA_HOME/bin/conda create -y --name $ENV_NAME python=3 pip
    fi
    source $CONDA_HOME/bin/activate $ENV_NAME
else
    echo "VENV_SYS not recognized"
    exit 1
fi
pip install --upgrade pip

rm -fr tmp_sdist
mkdir tmp_sdist
cd tmp_sdist
if [ "$C_COMPILER" = "gcc" ]; then
    CC=gcc CXX=g++ pip install --no-binary :all: -i https://testpypi.python.org/pypi orthpol
elif [ "$C_COMPILER" = "clang" ]; then
    CC=clang CXX=clang++ pip install --no-binary :all: -i https://testpypi.python.org/pypi orthpol
else
    echo "C_COMPILER not recognized"
    exit 1
fi
cd ..
rm -rf tmp_sdist

# Test import orthpol
echo "[UNITTESTS]"
python -c "import orthpol"

if [ "$VENV_SYS" = "virtualenv" ]; then
    deactivate
    rm -rf $ENV_DIR/$ENV_NAME
elif [ "$VENV_SYS" = "anaconda" ]; then
    source $CONDA_HOME/bin/deactivate
    $CONDA_HOME/bin/conda-env remove -y --name $ENV_NAME
fi
